# Pargen Examples

|Example  |Description              |
|---------|-------------------------|
| [arduino](./arduino)| A runnable Pargen example using the Arduino platform. The Pargen parameters are used as EEPROM data. The example is executable on the simavr simulator. It requires the [PlatformIO](https://platformio.org/) plugin.|
| [aurix_bmhdr](./aurix_bmhdr)| Shows how to use Pargen to generate boot mode header data structures for Aurix TC3xx micro controllers.|
| [safety](./safety)| Demonstrate how to define Parameter blocks with additional safety measures like block CRCs, identification and versioning.|
